==> safecheck-0.6.83-3.jar: safecheck/sqls/AggCheckerAnnualPlanPaged.sql <==
{
__n__ == $__n__$ :
$
	with rcq AS
	(
		select id, name, parentid, ename from (
			select name, id, parentid, '' ename from t_organization
			union all
			select name, id, parentid, ename from t_user) t where  t.id = {org_id}
		UNION ALL
		select a.id id, a.name name, a.parentid parentid, a.ename ename from (
			select name, id, parentid, '' ename from t_organization
			union all
			select name, id, parentid, ename from t_user) a
		INNER JOIN rcq s on s.id = a.parentid
	)
	select {f_aggregations} from (
		select * from t_check_plan where f_plan_year = {f_plan_year} 
		{
			f_subcompany != $$ :
			$
				and f_subcompany='{f_subcompany}'  
			$,
			$
			$
		}
		and f_checker in (select name from rcq where ename != '')
	) t
$,
$
	with rcq AS
	(
		select id, name, parentid, ename from (
			select name, id, parentid, '' ename from t_organization
			union all
			select name, id, parentid, ename from t_user) t where  t.id = {org_id}
		UNION ALL
		select a.id id, a.name name, a.parentid parentid, a.ename ename from (
			select name, id, parentid, '' ename from t_organization
			union all
			select name, id, parentid, ename from t_user) a
		INNER JOIN rcq s on s.id = a.parentid
	)

	select * from 
	(
		select t1.f_checker, task,
		{
		     entity.findDialect()==$SqlServer$:
             $ isnull(accomplished,0) accomplished,  $,
             $ nvl(accomplished,0) accomplished,  $
		}
		 ROW_NUMBER() OVER (ORDER BY t1.f_checker) AS rownum  from
		(
		select p.f_checker f_checker, count(*) task from t_check_plan p inner join t_check_plan_item i on p.id = i.f_plan_id where p.f_plan_year = {f_plan_year}
		{
			f_subcompany != $$ :
			$
				and p.f_subcompany='{f_subcompany}'  
			$,
			$
			$
		}
		and p.f_checker in (select name from rcq where ename != '')
		group by p.f_checker
		) t1 left join 
		(
		select f_checker_name f_checker, count(*) accomplished from t_check_paper 
		where 
		{
			f_subcompany != $$ :
			$
				f_subcompany='{f_subcompany}' and 
			$,
			$
			$
		}
		f_checker_name in (select name from rcq where ename != '') 
		and f_offsite_time > '{f_plan_year}-01-01' and f_offsite_time <= '{f_plan_year}-12-31 23:59:59' 
		and f_approved='已审核' 
		group by f_checker_name
		) t2
		on t1.f_checker = t2.f_checker
	) t where rownum between {__startRow__} and {__endRow__}
$
}

==> safecheck-0.9.8.6.jar: safecheck/sqls/AggCheckerAnnualPlanPaged.sql <==
{
__n__ == $__n__$ :
$
	with rcq AS
	(
		select id, name, parentid, ename from (
			select name, id, parentid, '' ename from t_organization
			union all
			select name, id, parentid, ename from t_user) t where  t.id = {org_id}
		UNION ALL
		select a.id id, a.name name, a.parentid parentid, a.ename ename from (
			select name, id, parentid, '' ename from t_organization
			union all
			select name, id, parentid, ename from t_user) a
		INNER JOIN rcq s on s.id = a.parentid
	)
	select {f_aggregations} from (
		select * from t_check_plan where f_plan_year = {f_plan_year} 
		{
			f_subcompany != $$ :
			$
				and f_subcompany='{f_subcompany}'  
			$,
			$
			$
		}
		and f_checker in (select name from rcq where ename != '')
	) t
$,
$
	with rcq AS
	(
		select id, name, parentid, ename from (
			select name, id, parentid, '' ename from t_organization
			union all
			select name, id, parentid, ename from t_user) t where  t.id = {org_id}
		UNION ALL
		select a.id id, a.name name, a.parentid parentid, a.ename ename from (
			select name, id, parentid, '' ename from t_organization
			union all
			select name, id, parentid, ename from t_user) a
		INNER JOIN rcq s on s.id = a.parentid
	)

	select * from 
	(
		select t1.f_checker, task, isnull(accomplished,0) accomplished, ROW_NUMBER() OVER (ORDER BY t1.f_checker) AS rownum  from 
		(
		select p.f_checker f_checker, count(*) task from t_check_plan p inner join t_check_plan_item i on p.id = i.f_plan_id where p.f_plan_year = {f_plan_year}
		{
			f_subcompany != $$ :
			$
				and p.f_subcompany='{f_subcompany}'  
			$,
			$
			$
		}
		and p.f_checker in (select name from rcq where ename != '')
		group by p.f_checker
		) t1 left join 
		(
		select f_checker_name f_checker, count(*) accomplished from t_check_paper 
		where 
		{
			f_subcompany != $$ :
			$
				f_subcompany='{f_subcompany}' and 
			$,
			$
			$
		}
		f_checker_name in (select name from rcq where ename != '') 
		and f_offsite_time > '{f_plan_year}-01-01' and f_offsite_time <= '{f_plan_year}-12-31 23:59:59' 
		and f_approved='已审核' 
		group by f_checker_name
		) t2
		on t1.f_checker = t2.f_checker
	) t where rownum between {__startRow__} and {__endRow__}
$
}
